@@ -4,7 +4,6 @@ Defines the EasyXmlTree class, which is a convenience wrapper around etree.
 The class exposes some helpful functions like css_select() and xpath().
 """
 
-from html import unescape
 from typing import Dict, List, Union, Optional
 import unicodedata
 
@@ -87,7 +86,7 @@ class EasyXmlTree:
 				sel = cssselect.CSSSelector(selector, translator="xhtml", namespaces=self.namespaces)
 				CSS_SELECTOR_CACHE[selector] = sel
 
-			return self.xpath(sel.path)
+			return [EasyXmlElement(element, self.namespaces) for element in sel(self.etree)]
 		except parser.SelectorSyntaxError as ex:
 			raise se.InvalidCssException(f"Invalid selector: [css]{selector}[/]") from ex
 
@@ -101,16 +100,12 @@ class EasyXmlTree:
 		result: List[Union[str, EasyXmlElement, float]] = []
 
 		try:
-			query_result = self.etree.xpath(selector, namespaces=self.namespaces)
-			if isinstance(query_result, etree._ElementUnicodeResult): # pylint: disable=protected-access
-				result.append(str(query_result))
-			elif isinstance(query_result, float):
+			query_result = self.etree.xpath(selector, namespaces=self.namespaces, smart_strings=False)
+			if isinstance(query_result, str|float):
 				result.append(query_result)
 			else:
 				for element in query_result:
-					if isinstance(element, etree._ElementUnicodeResult): # pylint: disable=protected-access
-						result.append(str(element))
-					elif isinstance(element, str):
+					if isinstance(element, str):
 						result.append(element)
 					else:
 						result.append(EasyXmlElement(element, self.namespaces))
@@ -231,16 +226,15 @@ class EasyXmlElement:
 		shorthand namespaces.
 
 		Example:
-		epub:type -> {http://www.idpf.org/2007/ops}:type
+		epub:type -> {http://www.idpf.org/2007/ops}type
 		"""
 
-		output = value
+		# The in check is redundant with the regex but is far more efficient
+		# when the value is un-namespaced
+		if ':' in value and self.namespaces:
+			value = regex.sub(r"^(\L<ns>):", lambda m: f"{{{self.namespaces[m[1]]}}}", value, ns=self.namespaces.keys())
 
-		if self.namespaces:
-			for name, identifier in self.namespaces.items():
-				output = regex.sub(fr"^{name}:", f"{{{identifier}}}", output)
-
-		return output
+		return value
 
 	def to_tag_string(self) -> str:
 		"""
@@ -376,16 +370,12 @@ class EasyXmlElement:
 
 		result: List[Union[str, EasyXmlElement, float]] = []
 
-		query_result = self.lxml_element.xpath(selector, namespaces=self.namespaces)
-		if isinstance(query_result, etree._ElementUnicodeResult): # pylint: disable=protected-access
-			result.append(str(query_result))
-		elif isinstance(query_result, float):
+		query_result = self.lxml_element.xpath(selector, namespaces=self.namespaces, smart_strings=False)
+		if isinstance(query_result, str|float):
 			result.append(query_result)
 		else:
 			for element in query_result:
-				if isinstance(element, etree._ElementUnicodeResult): # pylint: disable=protected-access
-					result.append(str(element))
-				elif isinstance(element, str):
+				if isinstance(element, str):
 					result.append(element)
 				else:
 					result.append(EasyXmlElement(element, self.namespaces))
@@ -423,7 +413,8 @@ class EasyXmlElement:
 		`<p>Hello there, <abbr>Mr.</abbr> Smith!</p>` -> `Hello there, Mr. Smith!`
 		"""
 
-		return unescape(regex.sub(r"<[^>]+?>", "", self.inner_xml().strip()))
+		text = etree.tostring(self.lxml_element, encoding=str, method="text", with_tail=False)
+		return text.strip()
 
 	def remove(self) -> None:
 		"""
