@@ -50,31 +50,34 @@ def semanticate(xhtml: str) -> str:
 	"""
 
 	# Some common abbreviations
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Mr\.", r"""<abbr epub:type="z3998:name-title">Mr.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Mrs\.", r"""<abbr epub:type="z3998:name-title">Mrs.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Ms\.", r"""<abbr epub:type="z3998:name-title">Ms.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Dr\.", r"""<abbr epub:type="z3998:name-title">Dr.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Drs\.", r"""<abbr epub:type="z3998:name-title">Drs.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Prof\.", r"""<abbr epub:type="z3998:name-title">Prof.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Rev\.", r"""<abbr epub:type="z3998:name-title">Rev.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Hon\.", r"""<abbr epub:type="z3998:name-title">Hon.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Lieut\.", r"""<abbr epub:type="z3998:name-title">Lieut.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Fr\.", r"""<abbr epub:type="z3998:name-title">Fr.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Lt\.", r"""<abbr epub:type="z3998:name-title">Lt.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Capt\.", r"""<abbr epub:type="z3998:name-title">Capt.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Pvt\.", r"""<abbr epub:type="z3998:name-title">Pvt.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Esq\.", r"""<abbr epub:type="z3998:name-title">Esq.</abbr>""", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))(\L<titles>\.)", r"""<abbr epub:type="z3998:name-title">\1</abbr>""", xhtml, titles=[
+		"Capt",
+		"Col",
+		"Dr",
+		"Drs",
+		"Esq",
+		"Fr",
+		"Hon",
+		"Lieut",
+		"Lt",
+		"MM",
+		"Mdlle",
+		"Messers",
+		"Messrs",
+		"Mlle",
+		"Mlles",
+		"Mme",
+		"Mmes",
+		"Mon",
+		"Mr",
+		"Mrs",
+		"Ms",
+		"Prof",
+		"Pvt",
+		"Rev",
+	])
 	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Bros\.", r"<abbr>Bros.</abbr>", xhtml)
 	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Mt\.", r"<abbr>Mt.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))MM\.", r"""<abbr epub:type="z3998:name-title">MM.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Mme\.", r"""<abbr epub:type="z3998:name-title">Mme.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Mmes\.", r"""<abbr epub:type="z3998:name-title">Mmes.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Mon\.", r"""<abbr epub:type="z3998:name-title">Mon.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Mlle\.", r"""<abbr epub:type="z3998:name-title">Mlle.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Mdlle\.", r"""<abbr epub:type="z3998:name-title">Mdlle.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Mlles\.", r"""<abbr epub:type="z3998:name-title">Mlles.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Messrs\.", r"""<abbr epub:type="z3998:name-title">Messrs.</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Messers\.", r"""<abbr epub:type="z3998:name-title">Messers.</abbr>""", xhtml)
 	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([Vv])ol(s?)\.", r"<abbr>\1ol\2.</abbr>", xhtml)
 	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([Cc])hap\. ([0-9])", r"<abbr>\1hap.</abbr> \2", xhtml) # The number allows us to avoid phrases like `Hello, old chap.`
 	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>)|\.)(P\.(?:P\.)?S\.(?:S\.)?\B)", r"""<abbr epub:type="z3998:initialism">\1</abbr>""", xhtml)
@@ -83,7 +86,6 @@ def semanticate(xhtml: str) -> str:
 	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Ltd\.", r"<abbr>Ltd.</abbr>", xhtml)
 	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))St\.", r"<abbr>St.</abbr>", xhtml)
 	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([Gg])ov\.", r"<abbr>\1ov.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Col\.", r"""<abbr epub:type="z3998:name-title">Col.</abbr>""", xhtml)
 	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))MS(S?)\.", r"""<abbr>MS\1.</abbr>""", xhtml)
 	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([Vv])iz\.", r"<abbr>\1iz.</abbr>", xhtml)
 	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))etc\.", r"<abbr>etc.</abbr>", xhtml)
@@ -360,16 +362,16 @@ def get_word_count(xhtml: str) -> int:
 	xhtml = regex.sub(r"<.+?>", " ", xhtml, flags=regex.DOTALL)
 
 	# Replace some formatting characters
-	xhtml = regex.sub(r"[…–—― ‘’“”\{\}\(\)]", " ", xhtml, flags=regex.IGNORECASE | regex.DOTALL)
+	xhtml = regex.sub(r"[…–—― ‘’“”\{\}\(\)]", " ", xhtml)
 
 	# Remove word-connecting dashes, apostrophes, commas, and slashes (and/or), they count as a word boundry but they shouldn't
-	xhtml = regex.sub(fr"[\p{{Letter}}0-9][\-\'\,\.\/{se.NO_BREAK_HYPHEN}{se.SHY_HYPHEN}][\p{{Letter}}0-9]", "aa", xhtml, flags=regex.IGNORECASE | regex.DOTALL)
+	xhtml = regex.sub(fr"[\p{{Letter}}0-9][\-\'\,\.\/{se.NO_BREAK_HYPHEN}{se.SHY_HYPHEN}][\p{{Letter}}0-9]", "aa", xhtml)
 
 	# Replace sequential spaces with one space
-	xhtml = regex.sub(r"\s+", " ", xhtml, flags=regex.IGNORECASE | regex.DOTALL)
+	xhtml = regex.sub(r"\s+", " ", xhtml)
 
 	# Get the word count
-	return len(regex.findall(r"\b\w+\b", xhtml, flags=regex.IGNORECASE | regex.DOTALL))
+	return len(regex.findall(r"\b\w+\b", xhtml))
 
 def _replace_character_references(match_object) -> str:
 	"""Replace most XML character references with literal characters.
@@ -658,13 +660,13 @@ def format_xhtml(xhtml: str) -> str:
 	xhtml = regex.sub(r"&#?\w+;", _replace_character_references, xhtml)
 
 	# Remove unnecessary doctypes which can cause xmllint to hang
-	xhtml = regex.sub(r"<!DOCTYPE[^>]+?>", "", xhtml, flags=regex.DOTALL)
+	xhtml = regex.sub(r"<!DOCTYPE[^>]+?>", "", xhtml)
 
 	# Remove white space between opening/closing tag and text nodes
 	# We do this first so that we can still format line breaks after <br/>
 	# Exclude comments
 	xhtml = regex.sub(r"(<(?:[^!/][^>]*?[^/]|[a-z])>)\s+([^\s<])", r"\1\2", xhtml, flags=regex.IGNORECASE)
-	xhtml = regex.sub(r"([^\s>])\s+(</[^>]+?>)", r"\1\2", xhtml, flags=regex.IGNORECASE)
+	xhtml = regex.sub(r"([^\s>])\s+(</[^>]+?>)", r"\1\2", xhtml)
 
 	try:
 		tree = _format_xml_str(xhtml)
@@ -1086,7 +1088,7 @@ def format_css(css: str) -> str:
 	output = regex.sub(r"(@[\p{Letter}]+) \(", "\\1(", output)
 
 	# Remove empty rules
-	output = regex.sub(r"^\t*[^\{\}]+?\{\s*\}\n", "", output, flags=regex.DOTALL|regex.MULTILINE)
+	output = regex.sub(r"^\t*[^\{\}]+?\{\s*\}\n", "", output, flags=regex.MULTILINE)
 
 	return output
 
@@ -1101,7 +1103,7 @@ def remove_tags(text: str) -> str:
 	A string with all HTML tags removed
 	"""
 
-	return regex.sub(r"</?[\p{Letter}]+[^>]*?>", "", text, flags=regex.DOTALL)
+	return regex.sub(r"</?[\p{Letter}]+[^>]*?>", "", text)
 
 def get_ordinal(number: str) -> str:
 	"""
@@ -1291,10 +1293,10 @@ def make_url_safe(text: str) -> str:
 	text = text.lower()
 
 	# 4. Remove apostrophes
-	text = regex.sub(r"['‘’]", "", text)
+	text = regex.sub(r"['‘’`]", "", text)
 
 	# 5. Convert any non-digit, non-letter character to a space
-	text = regex.sub(r"[^0-9\p{Letter}]", " ", text, flags=regex.IGNORECASE)
+	text = regex.sub(r"[^0-9\p{Letter}]", " ", text)
 
 	# 6. Convert any instance of one or more space to a dash
 	text = regex.sub(r"\s+", "-", text)
@@ -1531,7 +1533,7 @@ def _get_flattened_children(node: EasyXmlElement, allow_header: bool) -> List[Ea
 
 		if child.tag not in sectioning_elements and not is_endnote and not is_glossdef:
 			result.append(child)
-			result = result + _get_flattened_children(child, allow_header)
+			result += _get_flattened_children(child, allow_header)
 
 	return result
 
